aboutsummaryrefslogtreecommitdiffstats
path: root/agents/todo/tools.sh
diff options
context:
space:
mode:
Diffstat (limited to 'agents/todo/tools.sh')
-rwxr-xr-xagents/todo/tools.sh56
1 files changed, 38 insertions, 18 deletions
diff --git a/agents/todo/tools.sh b/agents/todo/tools.sh
index 0bb8f2b..c67109d 100755
--- a/agents/todo/tools.sh
+++ b/agents/todo/tools.sh
@@ -2,36 +2,50 @@
set -e
# @cmd Add a new todo item
-# @option --desc! The task description
+# @option --desc! The todo description
add_todo() {
todos_file="$(_get_todos_file)"
if [[ -f "$todos_file" ]]; then
- num="$(cat "$todos_file" | jq '[.[].id] | max + 1')"
data="$(cat "$todos_file")"
+ num="$(echo "$data" | jq '[.[].id] | max + 1')"
else
num=1
data="[]"
fi
echo "$data" | \
- jq --arg new_id $num \
- --arg new_desc "$argc_desc" \
- '. += [{"id": $new_id | tonumber, "desc": $new_desc}]' \
+ jq --arg new_id $num --arg new_desc "$argc_desc" \
+ '. += [{"id": $new_id | tonumber, "desc": $new_desc, "done": false}]' \
> "$todos_file"
echo "Successfully added todo id=$num" >> "$LLM_OUTPUT"
}
-# @cmd Delete an existing todo item
-# @option --id! <INT> The task id
+# @cmd Delete an todo item
+# @option --id! <INT> The todo id
del_todo() {
todos_file="$(_get_todos_file)"
if [[ -f "$todos_file" ]]; then
data="$(cat "$todos_file")"
echo "$data" | \
- jq --arg id $argc_id '[.[] | select(.id != ($id | tonumber))]' \
+ jq '[.[] | select(.id != '$argc_id')]' \
> "$todos_file"
echo "Successfully deleted todo id=$argc_id" >> "$LLM_OUTPUT"
else
- echo "Empty todo list" >> "$LLM_OUTPUT"
+ echo "The operation failed because the todo list is currently empty." >> "$LLM_OUTPUT"
+ fi
+}
+
+# @cmd Set a todo item status as done
+# @option --id! <INT> The todo id
+done_todo() {
+ todos_file="$(_get_todos_file)"
+ if [[ -f "$todos_file" ]]; then
+ data="$(cat "$todos_file")"
+ echo "$data" | \
+ jq '. |= map(if .id == '$argc_id' then .done = true else . end)' \
+ > "$todos_file"
+ echo "Successfully mark todo id=$argc_id as done" >> "$LLM_OUTPUT"
+ else
+ echo "The operation failed because the todo list is currently empty." >> "$LLM_OUTPUT"
fi
}
@@ -45,22 +59,28 @@ list_todos() {
fi
}
# @cmd Delete the entire todo list
clear_todos() {
todos_file="$(_get_todos_file)"
if [[ -f "$todos_file" ]]; then
- rm -rf "$todos_file" >> "$LLM_OUTPUT"
+ if [ -t 1 ]; then
+ read -r -p "Clean the entire todo list? [Y/n] " ans
+ if [[ "$ans" == "N" || "$ans" == "n" ]]; then
+ echo "Aborted!"
+ exit 1
+ fi
+ fi
+ rm -rf "$todos_file"
+ echo "Successfully cleaned the entire todo list" >> "$LLM_OUTPUT"
+ else
+ echo "The operation failed because the todo list is currently empty." >> "$LLM_OUTPUT"
fi
- echo "Successfully deleted entry todo list" >> "$LLM_OUTPUT"
-}
-
-_argc_before() {
- todos_file="$(_get_todos_file)"
- mkdir -p "$(dirname "$todos_file")"
}
_get_todos_file() {
- echo "${LLM_AGENT_CACHE_DIR:-/tmp}/todos.json"
+ todos_dir="${LLM_AGENT_CACHE_DIR:-.}"
+ mkdir -p "$todos_dir"
+ echo "$todos_dir/todos.json"
}
# See more details at https://github.com/sigoden/argc
@@ -45,22 +59,28 @@ list_todos() {
fi
}
-# @cmd Delete the entire todo list
+# @cmd Clean the entire todo list
clear_todos() {
todos_file="$(_get_todos_file)"